Struct TlsStreamTolerant
pub struct TlsStreamTolerant(pub TlsStream<TcpStream>);Expand description
Tolerates TLS streams from servers that omit close_notify (e.g. Exchange).
Tuple Fields
0: TlsStream<TcpStream>Trait Implementations
Sourceimpl AsyncRead for TlsStreamTolerant
impl AsyncRead for TlsStreamTolerant
Sourceimpl AsyncWrite for TlsStreamTolerant
impl AsyncWrite for TlsStreamTolerant
Sourcefn poll_write(
self: Pin<&mut Self>,
cx: &mut TaskContext<'_>,
buf: &[u8],
) -> Poll<Result<usize>>
fn poll_write( self: Pin<&mut Self>, cx: &mut TaskContext<'_>, buf: &[u8], ) -> Poll<Result<usize>>
Attempt to write bytes from
buf into the object. Read moreSourcefn poll_flush(
self: Pin<&mut Self>,
cx: &mut TaskContext<'_>,
) -> Poll<Result<()>>
fn poll_flush( self: Pin<&mut Self>, cx: &mut TaskContext<'_>, ) -> Poll<Result<()>>
Attempts to flush the object, ensuring that any buffered data reach
their destination. Read more
Sourcefn poll_shutdown(
self: Pin<&mut Self>,
cx: &mut TaskContext<'_>,
) -> Poll<Result<()>>
fn poll_shutdown( self: Pin<&mut Self>, cx: &mut TaskContext<'_>, ) -> Poll<Result<()>>
Initiates or attempts to shut down this writer, returning success when
the I/O connection has completely shut down. Read more
fn poll_write_vectored(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
bufs: &[IoSlice<'_>],
) -> Poll<Result<usize, Error>>
fn poll_write_vectored( self: Pin<&mut Self>, cx: &mut Context<'_>, bufs: &[IoSlice<'_>], ) -> Poll<Result<usize, Error>>
Like
poll_write, except that it writes from a slice of buffers. Read morefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
Determines if this writer has an efficient
poll_write_vectored
implementation. Read moreAuto Trait Implementations
impl !Freeze for TlsStreamTolerant
impl !RefUnwindSafe for TlsStreamTolerant
impl Send for TlsStreamTolerant
impl Sync for TlsStreamTolerant
impl Unpin for TlsStreamTolerant
impl UnsafeUnpin for TlsStreamTolerant
impl !UnwindSafe for TlsStreamTolerant