ImapSession

Type Alias ImapSession 

pub type ImapSession = Session<TlsStreamTolerant>;

Aliased Type

pub struct ImapSession {
    pub unsolicited_responses: Receiver<UnsolicitedResponse>,
    /* private fields */
}

Fields

unsolicited_responses: Receiver<UnsolicitedResponse>

Server responses that are not related to the current command. See also the note on unilateral server responses in RFC 3501.