Struct SessionsCurrentTool
pub struct SessionsCurrentTool { /* private fields */ }Expand description
Returns the session key and metadata for the currently active session.
Reads the session key from the TOOL_LOOP_SESSION_KEY task-local,
which is scoped around gateway and channel agent turns.
Implementations
Sourceimpl SessionsCurrentTool
impl SessionsCurrentTool
pub fn new(backend: Arc<dyn SessionBackend>) -> Self