Function clean_verbatim_path
pub fn clean_verbatim_path(path: &Path) -> PathBufExpand description
Adjusts a path on Windows to strip the UNC verbatim prefix \\?\ if present.
On Windows, cmd.exe and some legacy tools do not support paths starting with \\?\
as the current directory or within arguments.